@@ -70,7 +70,10 @@ class HttpServerConnector(AsyncOnStop):
         await self._requester._on_stop()
 
     def _get_url(self, path: str) -> str:
-        return str(yarl.URL(self.config.url) / path.lstrip('/'))
+        yarl_url = yarl.URL(self.config.url)
+        if path:
+            yarl_url = yarl_url / path.lstrip('/')
+        return str(yarl_url)
 
     async def post_json(self, path: str, payload: Jsonable, url_query: MultiMapping = None,
                         headers: Optional[Mapping[str, str]] = None, auth: Optional[BasicAuth] = None,
